import("data.table")
import("crayon")
import("wyz.code.offensiveProgramming")
importFrom("methods", "formalArgs", "getMethod", "is")
importFrom("utils", "methods", "combn")
importFrom("stats", "runif")
importFrom("tidyr", "separate")

export(
  qualifyFunctionArguments,
  opwf,
  offensiveProgrammingWrapFunction,
  # DataFactory,
  retrieveDataFactory,
  generateData,
  setGenerationContext,
  testFunction,
  computeArgumentsCombination,
  setDefaultArgumentsGenerationContext,
  usesSemanticArgumentNames,
  buildSemanticArgumentName,
  exploreSignatures,
  opMetaTestingInformation,

  # variables
  erc,
  established_replacement_context,
  dac,
  default_arguments_context
)

